@@ -1,15 +1,16 @@
-#include <qmime.h>
-#include <qprocess.h>
+#include <QProcess>
+#include <QVBoxLayout>
+#include <QFrame>
 
 #include "aboutdialog.h"
-#include "version.h"
 #include "settings.h"
-#include "mainwindow.h"
 
 
-extern Main *mainWindow;
 extern Settings settings;
 extern QString iconPath;
+extern QString vymVersion;
+extern QString vymBuildDate;
+extern QString vymCodeName;
 
 AboutDialog::AboutDialog( QWidget *parent, const char *name)
     : QDialog( parent, name)
@@ -18,14 +19,15 @@ AboutDialog::AboutDialog( QWidget *parent, const char *name)
     mainLayout=new QVBoxLayout( this, 10);
 
     tabs=new QTabWidget (this);
-    credits=new AboutTextBrowser (this,"credits");
+    credits=new AboutTextBrowser (parent,"credits");
 
-    credits->setText (
+    credits->setHtml(
 	"<center><img src=\""+iconPath+"vym-128x128.png\"></center>"
 	"<h3><center>VYM - View Your Mind </h3>"
 	"<p align=\"center\"> A tool to put the things you have got in your mind into a map.</p>"
 	"<p align=\"center\"> (c) by Uwe Drechsel (<a href=\"mailto:vym@InSilmaril.de\">vym@InSilmaril.de</a>)</p>"
-	"<p align=\"center\"> Version " __VYM_VERSION" - " __BUILD_DATE"</p>"
+	"<p align=\"center\"> Version " +vymVersion+" - " +vymBuildDate+"</p>"
+	"<p align=\"center\"> " +vymCodeName+"</p>"
 	"<ul>"
 	"<li> Contact</li>"
 		"<ul>"
@@ -42,23 +44,27 @@ AboutDialog::AboutDialog( QWidget *parent, const char *name)
 		"</ul>"		
 	"<li> Credits " 
 	"<ul>"
-	"<li>Jakob Hilmer for image drag and drop, &quot;About vym&quot; window patch </li>"
-	"<li>Thomas Schraitle for the stylesheet  used for XHTML-export </li>"
+	"<li>Peter Adams for documentation proofreading and polishing</li>"
+	"<li>Jakob Hilmer for image drag and drop in 1.8.1, &quot;About vym&quot; window patch </li>"
+	"<li>Thomas Schraitle for the stylesheet  used for XHTML-export and help with XML processing in general</li>"
 	"<li>Debianization by Christoph Thielecke and Steffen Joeris</li>"
-	"<li>Ken Wimer and Olaf Hering for Mac support</li>"
 	"<li>Matt from <a href=\"http://www.satbp.com\">www.satbp.com</a> for <a href=\"http://www.taskjuggler.org\">Taskjuggler</a> export</li>"
+	"<li>Olaf Hering for support with my Powerbook</li>"
+	"<li>All the guys at Trolltech for their Qt toolkit</li>"
+	"<li>All the guys at SuSE for their Linux and support, e.g. to get Linux running on PowerPC and also Macbooks</li>"
 	"</ul>"
 	"</li>");
     credits->setFrameStyle( QFrame::Panel | QFrame::Plain );
     tabs->addTab (credits,"Credits");
 
-    license=new AboutTextBrowser (this,"license");
-	//license->setTextFormat (PlainText);
+    license=new AboutTextBrowser (parent,"license");
     license->setText (
+	"<center>"
 	"<h3>VYM - View Your Mind</h3>"
-    "<p>Copyright (C) 2004-2005  Uwe Drechsel</p>"  
+    "<p>Copyright (C) 2004-2007  Uwe Drechsel</p>"  
+	"</center>"
 
-    "<p>This program is free software; you can redistribute it and/or modify it under the terms of the GNU General Public License as published by the Free Software Foundation; either version 2 of the License, or (at your option) any later version.</p>"
+    "<p>This program is free software; you can redistribute it and/or modify it under the terms of the GNU General Public License version 2 as published by the Free Software Foundation.</p>"
 
     "<p>This program is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License below for more details.</p>"
 
@@ -171,7 +177,7 @@ AboutDialog::AboutDialog( QWidget *parent, const char *name)
     tabs->showPage (credits);
 
     okbutton =new QPushButton (this,"okbutton");
-    okbutton->setText (tr("Ok"));
+    okbutton->setText (tr("Ok","Ok Button"));
     okbutton->setMaximumSize (QSize (50,30));
     okbutton->setAutoDefault (true);
     mainLayout->addWidget( okbutton); 
@@ -185,19 +191,15 @@ AboutTextBrowser::AboutTextBrowser(QWidget *parent, const char *name)
     
 }
 
-void AboutTextBrowser::setSource(const QString &name)
+void AboutTextBrowser::setSource(const QUrl &url )
 {
-    QMimeSourceFactory *factory = QMimeSourceFactory::defaultFactory();
-    const QMimeSource *data = factory->data(name);
-    if (data) {
-	QTextBrowser::setSource(name);
-    } else {
-	QProcess *proc = new QProcess( this );
-	proc->addArgument( settings.readEntry("/vym/mainwindow/readerURL" ));
-	proc->addArgument( name);
-	
-	if ( !proc->start() ) 
-	    if (mainWindow->settingsURL() ) 
-		setSource(name);
-    }
+	QProcess *proc= new QProcess ();
+	proc->start( settings.value("/mainwindow/readerURL").toString(),QStringList ()<<url.toString());
+	//if (!proc->waitForStarted() &&mainWindow->settingsURL() ) setSource(url);
+	if (!proc->waitForStarted() )
+		QMessageBox::warning(0, 
+		tr("Warning","About window"),
+		tr("Couldn't find a viewer to open %1.\n","About window").arg(url)+
+		tr("Please use Settings->")+tr("Set application to open an URL"));
+
 }
