@@ -6,7 +6,6 @@
 extern TextEditor *textEditor;
 extern Main *mainWindow;
 extern FlagRowObj *standardFlagsDefault;
-extern QAction *actionEditOpenURL;
 
 
 /////////////////////////////////////////////////////////////////
@@ -14,6 +13,7 @@ extern QAction *actionEditOpenURL;
 /////////////////////////////////////////////////////////////////
 
 BranchObj* BranchObj::itLast=NULL;
+BranchObj* BranchObj::itFirst=NULL;
 
 
 BranchObj::BranchObj () :OrnamentedObj()
@@ -24,40 +24,40 @@ BranchObj::BranchObj () :OrnamentedObj()
     depth=-1;
 }
 
-BranchObj::BranchObj (QCanvas* c):OrnamentedObj (c)
+BranchObj::BranchObj (QGraphicsScene* s):OrnamentedObj (s)
 {
-//    cout << "Const BranchObj (c)  called from MapCenterObj (c)\n";
+//    cout << "Const BranchObj (s)  called from MapCenterObj (s)\n";
 	parObj=NULL;
-    canvas=c;
+    scene=s;
 }
 
-BranchObj::BranchObj (QCanvas* c, LinkableMapObj* p):OrnamentedObj (c)
+BranchObj::BranchObj (QGraphicsScene* s, LinkableMapObj* p):OrnamentedObj (s)
 {
-//    cout << "Const BranchObj (c,p)\n";
-    canvas=c;
+//    cout << "Const BranchObj (s,p)\n";
+    scene=s;
     setParObj (p);	
     depth=p->getDepth()+1;
 	if (depth==1)
 		// Calc angle to mapCenter if I am a mainbranch
 		// needed for reordering the mainbranches clockwise 
 		// around mapcenter 
-		angle=getAngle (QPoint ((int)(x() - parObj->getChildPos().x() ), 
-								(int)(y() - parObj->getChildPos().y() ) ) );
+		angle=getAngle (QPointF (x() - parObj->getChildPos().x() , 
+								(y() - parObj->getChildPos().y() ) ) );
     init();
 }
 
 BranchObj::~BranchObj ()
 {
-//	cout << "Destr BranchObj of "<<this<<endl;
+	//cout << "Destr BranchObj of "<<this<<endl;
 	// Check, if this branch was the last child to be deleted
 	// If so, unset the scrolled flags
 
-	BranchObj *po=(BranchObj*)(parObj);
+	BranchObj *po=(BranchObj*)parObj;
 	BranchObj *bo;
 	if (po)
 	{
-		bo=((BranchObj*)(parObj))->getLastBranch();
-		if (!bo) po->unScroll();
+		bo=((BranchObj*)parObj)->getLastBranch();
+		if (bo) po->unScroll();
 	}
 	clear();
 }
@@ -72,30 +72,15 @@ bool BranchObj::operator== ( const BranchObj & other )
     return angle == other.angle;
 }
 
-int BranchObjPtrList::compareItems ( QPtrCollection::Item i, QPtrCollection::Item j)
-{
-	// Make sure PtrList::find works
-	if (i==j) return 0;
-
-	if ( ((BranchObj*)(i))->angle > ((BranchObj*)(j))->angle )
-		return 1;
-	else
-		return -1;
-}
-
 void BranchObj::init () 
 {
-    branch.setAutoDelete (false);
-    floatimage.setAutoDelete (true);
-    xlink.setAutoDelete (false);
-
 	if (parObj)
 	{
 		absPos=getRandPos();
 		absPos+=parObj->getChildPos();
 	}
 
-    lastSelectedBranch=-1;
+    lastSelectedBranch=0;
 
     setChildObj(this);
 
@@ -111,17 +96,14 @@ void BranchObj::copy (BranchObj* other)
     OrnamentedObj::copy(other);
 
 	branch.clear();
-    BranchObj* b;
-    for (b=other->branch.first(); b;b=other->branch.next() ) 
+	for (int i=0; i<other->branch.size(); ++i)
 		// Make deep copy of b
 		// Because addBranch again calls copy for the childs,
 		// Those will get a deep copy, too
-		addBranch(b);	
-
-	FloatImageObj *fi;
-	for (fi=other->floatimage.first(); fi;fi=other->floatimage.next() )
-		addFloatImage (fi);
+		addBranch(other->branch.at(i) );	
 
+	for (int i=0; i<other->floatimage.size(); ++i)
+		addFloatImage  (other->floatimage.at(i));
 	scrolled=other->scrolled;
 	tmpUnscrolled=other->tmpUnscrolled;
 	setVisibility (other->visible);
@@ -133,40 +115,42 @@ void BranchObj::copy (BranchObj* other)
 
 void BranchObj::clear() 
 {
-	floatimage.clear();
+	setVisibility (true);
+
+	while (!floatimage.isEmpty())
+		delete floatimage.takeFirst();
+
 	while (!xlink.isEmpty())
-		deleteXLink (xlink.first() );
+		delete xlink.takeFirst();
 
-	BranchObj *bo;
 	while (!branch.isEmpty())
-	{
-		bo=branch.first();
-		branch.removeFirst();
-		delete (bo);
-	}
+		delete branch.takeFirst();
+}
+
+bool isAbove (BranchObj* a, BranchObj *b)
+{
+	if (a->angle < b->angle)
+		return true;
+	else	
+		return false;
 }
 
 int BranchObj::getNum()
 {
 	if (parObj)
-		return ((BranchObj*)(parObj))->getNum ((BranchObj*)(this));
+		return ((BranchObj*)parObj)->getNum (this);
 	else
 		return 0;
 }
 
 int BranchObj::getNum(BranchObj *bo)
 {
-	// keep current pointer in branch, 
-	// otherwise save might fail
-	int cur=branch.at();
-	int ind=branch.findRef (bo);
-	branch.at(cur);
-	return ind;
+	return branch.indexOf (bo);
 }
 
 int BranchObj::getFloatImageNum(FloatImageObj *fio)
 {
-	return floatimage.findRef (fio);
+	return floatimage.indexOf(fio);
 }
 
 int BranchObj::countBranches()
@@ -184,7 +168,7 @@ int BranchObj::countXLinks()
 	return xlink.count();
 }
 
-void BranchObj::setParObjTmp(LinkableMapObj* lmo, QPoint m, int off)
+void BranchObj::setParObjTmp(LinkableMapObj* lmo, QPointF m, int off)
 {
 	// Temporary link to lmo
 	// m is position of mouse pointer 
@@ -215,17 +199,17 @@ void BranchObj::setParObjTmp(LinkableMapObj* lmo, QPoint m, int off)
 	if (depth==1)
 	{	// new parent is the mapcenter itself
 
-		QPoint p= normalise ( QPoint (m.x() - o->getChildPos().x(),
+		QPointF p= normalise ( QPointF (m.x() - o->getChildPos().x(),
 									  m.y() - o->getChildPos().y() ));
 		if (p.x()<0) p.setX( p.x()-bbox.width() );
 		move2RelPos (p);
 	} else
 	{	
-		int y;
+		qreal y;
 		if (off==0)
 		{
 			// new parent is just a branch, link to it
-			QRect t=o->getBBoxSizeWithChilds();
+			QRectF t=o->getBBoxSizeWithChilds();
 			if (o->getLastBranch())
 				y=t.y() + t.height() ;
 			else
@@ -243,14 +227,14 @@ void BranchObj::setParObjTmp(LinkableMapObj* lmo, QPoint m, int off)
 				// Don't try to find that branch, guess 12 pixels
 				y=o->getChildPos().y()  -height() + 12; 
 		}	
-		if (o->getOrientation()==OrientLeftOfCenter)
+		if (o->getOrientation()==LinkableMapObj::LeftOfCenter)
 			move ( o->getChildPos().x() - linkwidth, y );
 		else	
 			move (o->getChildPos().x() + linkwidth, y );
 	}	
 
 	// updateLink is called implicitly in move
-	reposition();	// FIXME shouldn't be this a request?
+	requestReposition();	
 }
 
 void BranchObj::unsetParObjTmp()
@@ -274,23 +258,18 @@ void BranchObj::unScroll()
 
 void BranchObj::toggleScroll()
 {
-	BranchObj *bo;
 	if (scrolled)
 	{
 		scrolled=false;
 		systemFlags->deactivate("scrolledright");
-		for (bo=branch.first(); bo; bo=branch.next() )
-		{
-			bo->setVisibility(true);
-		}
+		for (int i=0; i<branch.size(); ++i)
+			branch.at(i)->setVisibility(true);
 	} else
 	{
 		scrolled=true;
 		systemFlags->activate("scrolledright");
-		for (bo=branch.first(); bo; bo=branch.next() )
-		{
-			bo->setVisibility(false);
-		}
+		for (int i=0; i<branch.size(); ++i)
+			branch.at(i)->setVisibility(false);
 	}
 	calcBBoxSize();
 	positionBBox();	
@@ -363,15 +342,13 @@ void BranchObj::setVisibility(bool v, int toDepth)
 		if (!scrolled && (depth < toDepth))
 		{
 			// Now go recursivly through all childs
-			BranchObj* b;
-			for (b=branch.first(); b;b=branch.next() ) 
-				b->setVisibility (v,toDepth);	
-			FloatImageObj *fio;
-			for (fio=floatimage.first(); fio; fio=floatimage.next())
-				fio->setVisibility (v);
-			XLinkObj* xlo;
-			for (xlo=xlink.first(); xlo;xlo=xlink.next() ) 
-				xlo->setVisibility ();	
+			int i;
+			for (i=0; i<branch.size(); ++i)
+				branch.at(i)->setVisibility (v,toDepth);	
+			for (i=0; i<floatimage.size(); ++i)
+				floatimage.at(i)->setVisibility (v);
+			for (i=0; i<xlink.size(); ++i)	
+				xlink.at(i)->setVisibility ();	
 		}
     } // depth <= toDepth	
 	requestReposition();
@@ -389,48 +366,57 @@ void BranchObj::setLinkColor ()
 	// BranchObj can use color of heading
 
 	if (mapEditor)
-		if (mapEditor->getLinkColorHint()==HeadingColor)
+		if (mapEditor->getMapLinkColorHint()==HeadingColor)
 			LinkableMapObj::setLinkColor (heading->getColor() );
 		else	
 			LinkableMapObj::setLinkColor ();
 }
 
-void BranchObj::setColorChilds (QColor col)
+void BranchObj::setColorSubtree(QColor col)
 {
 	OrnamentedObj::setColor (col);
-	BranchObj *bo;
-	for (bo=branch.first(); bo; bo=branch.next() )
-		bo->setColorChilds(col);
+	for (int i=0; i<branch.size(); ++i)
+		branch.at(i)->setColorSubtree(col);
 }
 
 BranchObj* BranchObj::first()
 {
 	itLast=NULL;	
+	itFirst=this;
 	return this; 
 }
 	
 BranchObj* BranchObj::next()
 {
+	BranchObj *bo;
 	BranchObj *lmo;
-	BranchObj *bo=branch.first();
-	BranchObj *po=(BranchObj*)(parObj);
+	BranchObj *po=(BranchObj*)parObj;
+
+	if (branch.isEmpty())
+		bo=NULL;
+	else
+		bo=branch.first();
 
 	if (!itLast)
-	{	// We are just beginning at the mapCenter
+	{
+		// no itLast, we are just beginning
 		if (bo) 
 		{
+			// we have childs, return first one
 			itLast=this;
 			return bo;
 		}	
 		else
 		{
-			itLast=NULL;
+			// No childs, so there is no next
+			itLast=this;
 			return NULL;
 		}	
 	}
 
-	if (itLast==parObj)
-	{	// We come from above
+	// We have an itLast
+	if (itLast==po)
+	{	// We come from parent
 		if (bo)
 		{
 			// there are childs, go there
@@ -441,7 +427,7 @@ BranchObj* BranchObj::next()
 		{	// no childs, try to go up again
 			if (po)
 			{
-				// go up
+				// go back to parent and try to find next there
 				itLast=this;
 				lmo=po->next();
 				itLast=this;
@@ -450,22 +436,35 @@ BranchObj* BranchObj::next()
 			}	
 			else
 			{
-				// can't go up, I am mapCenter
+				// can't go up, I am mapCenter, no next
 				itLast=NULL;
 				return NULL;
 			}	
 		}
 	}
 
-	// Try to find last child, we came from, in my own childs
+	// We don't come from parent, but from brother or childs
+
+	// Try to find last child, where we came from, in my own childs
 	bool searching=true;
-	while (bo && searching)
+	int i=0;
+	while (i<branch.size())
 	{
-		if (itLast==bo) searching=false;
-		bo=branch.next();
+		// Try to find itLast in my own childs
+		if (itLast==branch.at(i))
+		{
+			// ok, we come from my own childs
+			if (i<branch.size()-1)
+				bo=branch.at(i+1);
+			 else
+				bo=NULL;
+			searching=false;
+			i=branch.size();
+		} 	
+		++i;	
 	}
 	if (!searching)
-	{	// found lastLMO in my childs
+	{	// found itLast in my childs
 		if (bo)
 		{
 			// found a brother of lastLMO 
@@ -476,6 +475,7 @@ BranchObj* BranchObj::next()
 		{
 			if (po)
 			{
+				if (this==itFirst) return NULL;	// Stop at starting point
 				// go up
 				itLast=this;
 				lmo=po->next();
@@ -492,12 +492,11 @@ BranchObj* BranchObj::next()
 	}
 
 	// couldn't find last child, it must be a nephew of mine
-	bo=branch.first();
-	if (bo)
+	if (branch.size()>0)
 	{
 		// proceed with my first child
 		itLast=this;	
-		return bo;
+		return branch.first();
 	}	
 	else
 	{
@@ -531,22 +530,20 @@ void BranchObj::setLastIterator(BranchObj* it)
 
 void BranchObj::positionContents()
 {
-	FloatImageObj *fio;
-    for (fio=floatimage.first(); fio; fio=floatimage.next() )
-		fio->reposition();
+    for (int i=0; i<floatimage.size(); ++i )
+		floatimage.at(i)->reposition();
 	OrnamentedObj::positionContents();
 }
 
 void BranchObj::move (double x, double y)
 {
 	OrnamentedObj::move (x,y);
-	FloatImageObj *fio;
-    for (fio=floatimage.first(); fio; fio=floatimage.next() )
-		fio->reposition();
+    for (int i=0; i<floatimage.size(); ++i )
+		floatimage.at(i)->reposition();
     positionBBox();
 }
 
-void BranchObj::move (QPoint p)
+void BranchObj::move (QPointF p)
 {
 	move (p.x(), p.y());
 }
@@ -554,13 +551,12 @@ void BranchObj::move (QPoint p)
 void BranchObj::moveBy (double x, double y)
 {
 	OrnamentedObj::moveBy (x,y);
-    BranchObj* b;
-    for (b=branch.first(); b;b=branch.next() ) 
-		b->moveBy (x,y);
+	for (int i=0; i<branch.size(); ++i)
+		branch.at(i)->moveBy (x,y);
     positionBBox();
 }
 	
-void BranchObj::moveBy (QPoint p)
+void BranchObj::moveBy (QPointF p)
 {
 	moveBy (p.x(), p.y());
 }
@@ -568,33 +564,31 @@ void BranchObj::moveBy (QPoint p)
 
 void BranchObj::positionBBox()
 {
-	QPoint ap=getAbsPos();
+	QPointF ap=getAbsPos();
 	bbox.moveTopLeft (ap);
 	positionContents();
-	setSelBox();
 
 	// set the frame
-	frame->setRect(QRect(bbox.x(),bbox.y(),bbox.width(),bbox.height() ) );
+	frame->setRect(QRectF(bbox.x(),bbox.y(),bbox.width(),bbox.height() ) );
 
 	// Update links to other branches
-	XLinkObj *xlo;
-    for (xlo=xlink.first(); xlo; xlo=xlink.next() )
-		xlo->updateXLink();
+	for (int i=0; i<xlink.size(); ++i)
+		xlink.at(i)->updateXLink();
 }
 
 void BranchObj::calcBBoxSize()
 {
-    QSize heading_r=heading->getSize();
-    int heading_w=(int) heading_r.width() ;
-    int heading_h=(int) heading_r.height() ;
-    QSize sysflags_r=systemFlags->getSize();
-	int sysflags_h=sysflags_r.height();
-	int sysflags_w=sysflags_r.width();
-    QSize stanflags_r=standardFlags->getSize();
-	int stanflags_h=stanflags_r.height();
-	int stanflags_w=stanflags_r.width();
-    int w;
-    int h;
+    QSizeF heading_r=heading->getSize();
+    qreal heading_w=(qreal) heading_r.width() ;
+    qreal heading_h=(qreal) heading_r.height() ;
+    QSizeF sysflags_r=systemFlags->getSize();
+	qreal sysflags_h=sysflags_r.height();
+	qreal sysflags_w=sysflags_r.width();
+    QSizeF stanflags_r=standardFlags->getSize();
+	qreal stanflags_h=stanflags_r.height();
+	qreal stanflags_w=stanflags_r.width();
+    qreal w;
+    qreal h;
 
 	// set width to sum of all widths
 	w=heading_w + sysflags_w + stanflags_w;
@@ -603,44 +597,43 @@ void BranchObj::calcBBoxSize()
 	h=max (h,heading_h);
 
 	// Save the dimension of flags and heading
-	ornamentsBBox.setSize ( QSize(w,h));
+	ornamentsBBox.setSize ( QSizeF(w,h));
 
 	// clickBox includes Flags and Heading
     clickBox.setSize (ornamentsBBox.size() );
 
 	// Floatimages 
-	QPoint rp;
-	FloatImageObj *foi;
+	QPointF rp;
 
 	topPad=botPad=leftPad=rightPad=0;
 	if (includeImagesVer || includeImagesHor)
 	{
 		if (countFloatImages()>0)
 		{
-			for (foi=floatimage.first(); foi; foi=floatimage.next() )
+			for (int i=0; i<floatimage.size(); ++i )
 			{
-				rp=foi->getRelPos();
+				rp=floatimage.at(i)->getRelPos();
 				if (includeImagesVer)
 				{
 					if (rp.y() < 0) 
 						topPad=max (topPad,-rp.y()-h);
-					if (rp.y()+foi->height() > 0)
-						botPad=max (botPad,rp.y()+foi->height());
+					if (rp.y()+floatimage.at(i)->height() > 0)
+						botPad=max (botPad,rp.y()+floatimage.at(i)->height());
 				}		
 				if (includeImagesHor)
 				{
-					if (orientation==OrientRightOfCenter)
+					if (orientation==LinkableMapObj::RightOfCenter)
 					{
 						if (-rp.x()-w > 0) 
 							leftPad=max (leftPad,-rp.x()-w);
-						if (rp.x()+foi->width() > 0)
-							rightPad=max (rightPad,rp.x()+foi->width());
+						if (rp.x()+floatimage.at(i)->width() > 0)
+							rightPad=max (rightPad,rp.x()+floatimage.at(i)->width());
 					} else
 					{
 						if (rp.x()< 0) 
 							leftPad=max (leftPad,-rp.x());
-						if (rp.x()+foi->width() > w)
-							rightPad=max (rightPad,rp.x()+foi->width()-w);
+						if (rp.x()+floatimage.at(i)->width() > w)
+							rightPad=max (rightPad,rp.x()+floatimage.at(i)->width()-w);
 					}
 				}		
 			}	
@@ -650,52 +643,87 @@ void BranchObj::calcBBoxSize()
 	}
 
 	// Frame thickness
-    w+=frame->getBorder();
-    h+=frame->getBorder();
+    w+=frame->getPadding();
+    h+=frame->getPadding();
 	
 	// Finally set size
-    bbox.setSize (QSize (w,h));
+    bbox.setSize (QSizeF (w,h));
 }
 
 void BranchObj::setDockPos()
 {
-	if (getOrientation()==OrientLeftOfCenter )
+	// Sets childpos and parpos depending on orientation
+	if (getOrientation()==LinkableMapObj::LeftOfCenter )
     {
-		childPos=QPoint (ornamentsBBox.bottomLeft().x(), ornamentsBBox.bottomLeft().y() );
-		parPos=QPoint (ornamentsBBox.bottomRight().x(),ornamentsBBox.bottomRight().y() );
+		childPos=QPointF (
+			ornamentsBBox.bottomLeft().x(), 
+			bottomlineY);
+		parPos=QPointF (
+			ornamentsBBox.bottomRight().x(),
+			bottomlineY);
     } else
     {
-		childPos=QPoint (ornamentsBBox.bottomRight().x(), ornamentsBBox.bottomRight().y() );
-		parPos=QPoint (ornamentsBBox.bottomLeft().x(),ornamentsBBox.bottomLeft().y() );
+		childPos=QPointF (
+			ornamentsBBox.bottomRight().x(), 
+			bottomlineY);
+		parPos=QPointF (
+			ornamentsBBox.bottomLeft().x(),
+			bottomlineY);
     }
 }
-LinkableMapObj* BranchObj::findMapObj(QPoint p, LinkableMapObj* excludeLMO)
+
+LinkableMapObj* BranchObj::findMapObj(QPointF p, LinkableMapObj* excludeLMO)
 {
 	// Search branches
-    BranchObj *b;
     LinkableMapObj *lmo;
-    for (b=branch.first(); b; b=branch.next() )
+	for (int i=0; i<branch.size(); ++i)
     {	
-		lmo=b->findMapObj(p, excludeLMO);
+		lmo=branch.at(i)->findMapObj(p, excludeLMO);
 		if (lmo != NULL) return lmo;
     }
 	
+
 	// Search myself
     if (inBox (p) && (this != excludeLMO) && isVisibleObj() ) 
 		return this;
 
 	// Search float images
-	FloatImageObj *foi;
-    for (foi=floatimage.first(); foi; foi=floatimage.next() )
-		if (foi->inBox(p) && 
-			(foi != excludeLMO) && 
-			foi->getParObj()!= excludeLMO &&
-			foi->isVisibleObj() 
-		) return foi;
+    for (int i=0; i<floatimage.size(); ++i )
+		if (floatimage.at(i)->inBox(p) && 
+			(floatimage.at(i) != excludeLMO) && 
+			floatimage.at(i)->getParObj()!= excludeLMO &&
+			floatimage.at(i)->isVisibleObj() 
+		) return floatimage.at(i);
 
     return NULL;
 }
 
+LinkableMapObj* BranchObj::findID (QString sid)
+{
+	// Search branches
+    LinkableMapObj *lmo;
+	for (int i=0; i<branch.size(); ++i)
+    {	
+		lmo=branch.at(i)->findID (sid);
+		if (lmo != NULL) return lmo;
+    }
+	
+	// Search myself
+	if (sid==objID) return this;
+
+
+/*
+	// Search float images
+    for (int i=0; i<floatimage.size(); ++i )
+		if (floatimage.at(i)->inBox(p) && 
+			(floatimage.at(i) != excludeLMO) && 
+			floatimage.at(i)->getParObj()!= excludeLMO &&
+			floatimage.at(i)->isVisibleObj() 
+		) return floatimage.at(i);
+*/
+    return NULL;
+}
+
 void BranchObj::setHeading(QString s)
 {
     heading->setText(s);	// set new heading
@@ -719,9 +747,8 @@ void BranchObj::setHideTmp (HideTmpMode mode)
 		hidden=false;
 	}	
 
-    BranchObj *bo;
-    for (bo=branch.first(); bo; bo=branch.next() )
-		bo->setHideTmp (mode);
+	for (int i=0; i<branch.size(); ++i)
+		branch.at(i)->setHideTmp (mode);
 }
 
 bool BranchObj::hasHiddenExportParent(BranchObj *start)
@@ -738,10 +765,14 @@ bool BranchObj::hasHiddenExportParent(BranchObj *start)
 		return false;
 }
 
-QString BranchObj::saveToDir (const QString &tmpdir,const QString &prefix, const QPoint& offset)
+QString BranchObj::saveToDir (const QString &tmpdir,const QString &prefix, const QPointF& offset)
 {
+	// Cloudy stuff can be hidden during exports
 	if (hidden) return "";
 
+	// Update of note is usually done while unselecting a branch
+	if (isNoteInEditor) getNoteFromTextEditor();
+	
     QString s,a;
 	QString scrolledAttr;
 	if (scrolled) 
@@ -749,21 +780,15 @@ QString BranchObj::saveToDir (const QString &tmpdir,const QString &prefix, const
 	else
 		scrolledAttr="";
 
-	QString frameAttr;
-	if (frame->getFrameType()!=NoFrame)
-		frameAttr=attribut ("frameType",frame->getFrameTypeName());
-	else
-		frameAttr="";
-
 	// save area, if not scrolled
 	QString areaAttr;
 	if (!((BranchObj*)(parObj))->isScrolled() )
 	{
 		areaAttr=
-			attribut("x1",QString().setNum(absPos.x()-offset.x(),10)) +
-			attribut("y1",QString().setNum(absPos.y()-offset.y(),10)) +
-			attribut("x2",QString().setNum(absPos.x()+width()-offset.x(),10)) +
-			attribut("y2",QString().setNum(absPos.y()+height()-offset.y(),10));
+			attribut("x1",QString().setNum(absPos.x()-offset.x())) +
+			attribut("y1",QString().setNum(absPos.y()-offset.y())) +
+			attribut("x2",QString().setNum(absPos.x()+width()-offset.x())) +
+			attribut("y2",QString().setNum(absPos.y()+height()-offset.y()));
 
 	} else
 		areaAttr="";
@@ -778,7 +803,6 @@ QString BranchObj::saveToDir (const QString &tmpdir,const QString &prefix, const
     s=beginElement ("branch" 
 		+getOrnAttr() 
 		+scrolledAttr 
-		+frameAttr 
 		+areaAttr 
 		+idAttr 
 		+getIncludeImageAttr() );
@@ -788,31 +812,31 @@ QString BranchObj::saveToDir (const QString &tmpdir,const QString &prefix, const
     s+=valueElement("heading", getHeading(),
 		attribut ("textColor",QColor(heading->getColor()).name()));
 
+	// Save frame
+	if (frame->getFrameType()!=FrameObj::NoFrame) 
+		s+=frame->saveToDir ();
+
 	// save names of flags set
 	s+=standardFlags->saveToDir(tmpdir,prefix,0);
 	
+	// Save FloatImages
+	for (int i=0; i<floatimage.size(); ++i)
+		s+=floatimage.at(i)->saveToDir (tmpdir,prefix);
+
 	// save note
 	if (!note.isEmpty() )
 		s+=note.saveToDir();
 	
 	// Save branches
-    BranchObj *bo;
-    for (bo=branch.first(); bo; bo=branch.next() )
-		s+=bo->saveToDir(tmpdir,prefix,offset);
-
-	// Save FloatImages
-	FloatImageObj *fio;
-	for (fio=floatimage.first(); fio; fio=floatimage.next() )
-		s+=fio->saveToDir (tmpdir,prefix,offset);
+	for (int i=0; i<branch.size(); ++i)
+		s+=branch.at(i)->saveToDir(tmpdir,prefix,offset);
 
 	// Save XLinks
-	XLinkObj *xlo;
-	//FIXME exponential increase in xlinks...
 	QString ol;	// old link
 	QString cl;	// current link
-    for (xlo=xlink.first(); xlo; xlo=xlink.next() )
+	for (int i=0; i<xlink.size(); ++i)
 	{
-		cl=xlo->saveToDir();
+		cl=xlink.at(i)->saveToDir();
 		if (cl!=ol)
 		{
 			s+=cl;
@@ -836,7 +860,7 @@ void BranchObj::addXLink (XLinkObj *xlo)
 
 void BranchObj::removeXLinkRef (XLinkObj *xlo)
 {
-	xlink.remove (xlo);
+	xlink.removeAt (xlink.indexOf(xlo));
 }
 
 void BranchObj::deleteXLink(XLinkObj *xlo)
@@ -865,10 +889,12 @@ int BranchObj::countXLink()
 
 BranchObj* BranchObj::XLinkTargetAt (int i)
 {
-	if (xlink.at(i))
-		return xlink.at(i)->otherBranch (this);
-	else
-		return NULL;
+	if (i>=0 && i<xlink.size())
+	{
+		if (xlink.at(i))
+			return xlink.at(i)->otherBranch (this);
+	}
+	return NULL;
 }
 
 void BranchObj::setIncludeImagesVer(bool b)
@@ -877,7 +903,6 @@ void BranchObj::setIncludeImagesVer(bool b)
 	calcBBoxSize();
 	positionBBox();
 	requestReposition();
-	//FIXME undo needed
 }
 
 bool BranchObj::getIncludeImagesVer()
@@ -891,7 +916,6 @@ void BranchObj::setIncludeImagesHor(bool b)
 	calcBBoxSize();
 	positionBBox();
 	requestReposition();
-	//FIXME undo needed
 }
 
 bool BranchObj::getIncludeImagesHor()
@@ -913,35 +937,37 @@ QString BranchObj::getIncludeImageAttr()
 	return a;	
 }
 
-LinkableMapObj* BranchObj::addFloatImage ()
+FloatImageObj* BranchObj::addFloatImage ()
 {
-	FloatImageObj *newfi=new FloatImageObj (canvas,this);
+	FloatImageObj *newfi=new FloatImageObj (scene,this);
 	floatimage.append (newfi);
 	if (hasScrolledParent(this) )
 		newfi->setVisibility (false);
 	else	
 		newfi->setVisibility(visible);
+		/*
 	calcBBoxSize();
 	positionBBox();
+	*/
 	requestReposition();
 	return newfi;
-	//FIXME undo needed
 }
 
-LinkableMapObj* BranchObj::addFloatImage (FloatImageObj *fio)
+FloatImageObj* BranchObj::addFloatImage (FloatImageObj *fio)
 {
-	FloatImageObj *newfi=new FloatImageObj (canvas,this);
+	FloatImageObj *newfi=new FloatImageObj (scene,this);
 	floatimage.append (newfi);
 	newfi->copy (fio);
 	if (hasScrolledParent(this) )
 		newfi->setVisibility (false);
 	else	
 		newfi->setVisibility(visible);
+		/*
 	calcBBoxSize();
 	positionBBox();
+	*/
 	requestReposition();
 	return newfi;
-	// FIMXE undo needed
 }
 
 FloatImageObj* BranchObj::getFirstFloatImage ()
@@ -961,23 +987,18 @@ FloatImageObj* BranchObj::getFloatImageNum (const uint &i)
 
 void BranchObj::removeFloatImage (FloatImageObj *fio)
 {
-	floatimage.remove (fio);
+	int i=floatimage.indexOf (fio);
+	if (i>-1) delete (floatimage.takeAt (i));
 	calcBBoxSize();
 	positionBBox();
 	requestReposition();
-	// FIMXE undo needed
 }
 
 void BranchObj::savePosInAngle ()
 {
 	// Save position in angle
-    BranchObj *b;
-	int i=0;
-    for (b=branch.first(); b; b=branch.next() )
-	{
-		b->angle=i;
-		i++;
-	}
+	for (int i=0; i<branch.size(); ++i)
+		branch.at(i)->angle=i;
 }
 
 void BranchObj::setDefAttr (BranchModification mod)
@@ -1004,7 +1025,7 @@ void BranchObj::setDefAttr (BranchModification mod)
 
 BranchObj* BranchObj::addBranch()
 {
-    BranchObj* newbo=new BranchObj(canvas,this);
+    BranchObj* newbo=new BranchObj(scene,this);
     branch.append (newbo);
     newbo->setParObj(this);
 	newbo->setDefAttr(NewBranch);
@@ -1020,7 +1041,7 @@ BranchObj* BranchObj::addBranch()
 
 BranchObj* BranchObj::addBranch(BranchObj* bo)
 {
-    BranchObj* newbo=new BranchObj(canvas,this);
+    BranchObj* newbo=new BranchObj(scene,this);
     branch.append (newbo);
     newbo->copy(bo);
     newbo->setParObj(this);
@@ -1051,7 +1072,7 @@ BranchObj* BranchObj::insertBranch(int pos)
 	// Add new bo and resort branches
 	BranchObj *newbo=addBranch ();
 	newbo->angle=pos-0.5;
-	branch.sort();
+	qSort (branch.begin(),branch.end(), isAbove);
 	return newbo;
 }
 
@@ -1061,7 +1082,7 @@ BranchObj* BranchObj::insertBranch(BranchObj* bo, int pos)
 	// Add new bo and resort branches
 	bo->angle=pos-0.5;
 	BranchObj *newbo=addBranch (bo);
-	branch.sort();
+	qSort (branch.begin(),branch.end(), isAbove);
 	return newbo;
 }
 
@@ -1076,7 +1097,7 @@ BranchObj* BranchObj::insertBranchPtr (BranchObj* bo, int pos)
 	bo->setDefAttr (MovedBranch);
 	if (scrolled) tmpUnscroll();
 	setLastSelectedBranch (bo);
-	branch.sort();
+	qSort (branch.begin(),branch.end(), isAbove);
 	return bo;
 }
 
@@ -1089,7 +1110,7 @@ void BranchObj::removeBranchHere(BranchObj* borem)
 	int pos=borem->getNum();
 	while (bo)
 	{
-		bo->moveBranchTo (this,pos+1);
+		bo->linkTo (this,pos+1);
 		bo=borem->getLastBranch();
 	}	
 	removeBranch (borem);
@@ -1105,52 +1126,71 @@ void BranchObj::removeBranch(BranchObj* bo)
     // if bo is not in branch remove returns false, we
     // don't care...
 	
-    if (branch.remove (bo))
+	int i=branch.indexOf(bo);
+    if (i>=0)
+	{
 		delete (bo);
-	else
+		branch.removeAt (i);
+	} else
 		qWarning ("BranchObj::removeBranch tried to remove non existing branch?!\n");
 	requestReposition();
 }
 
 void BranchObj::removeBranchPtr(BranchObj* bo)
 {
-	branch.remove (bo);
+	int i=branch.indexOf(bo);
+	
+	if (i>=0)
+		branch.removeAt (i);
+	else	
+		qWarning ("BranchObj::removeBranchPtr tried to remove non existing branch?!\n");
 	requestReposition();
 }
 
 void BranchObj::setLastSelectedBranch (BranchObj* bo)
 {
-    lastSelectedBranch=branch.find(bo);
+    lastSelectedBranch=branch.indexOf(bo);
 }
 
 BranchObj* BranchObj::getLastSelectedBranch ()
 {
-    if (lastSelectedBranch>=0) 
+    if (lastSelectedBranch>=0)
 	{
-		BranchObj* bo=branch.at(lastSelectedBranch);
-		if (bo) return bo;
-    }	
-    return branch.first();
+		if ( branch.size()>lastSelectedBranch) 
+			return branch.at(lastSelectedBranch);
+		if (branch.size()>0)
+			return branch.last();
+	}	
+    return NULL;
 }
 
 BranchObj* BranchObj::getFirstBranch ()
 {
-    return branch.first();
+	if (branch.size()>0)
+		return branch.first();
+	else
+		return NULL;
 }
 
 BranchObj* BranchObj::getLastBranch ()
 {
-    return branch.last();
+	if (branch.size()>0)
+		return branch.last();
+	else
+		return NULL;
 }
 
-BranchObj* BranchObj::getBranchNum (const uint &i)
+BranchObj* BranchObj::getBranchNum (int i)
 {
-    return branch.at(i);
+	if (i>=0 && i<branch.size())
+		return branch.at(i);
+	else	
+		return	NULL;
 }
 
 bool BranchObj::canMoveBranchUp() 
 {
-	if (!parObj) return false;
+	if (!parObj || depth==1) return false;
 	BranchObj* par=(BranchObj*)parObj;
 	if (this==par->getFirstBranch())
 		return false;
@@ -1158,23 +1198,23 @@ bool BranchObj::canMoveBranchUp()
 		return true;
 }
 
-BranchObj* BranchObj::moveBranchUp(BranchObj* bo1) // move a branch up (modify myself)
+BranchObj* BranchObj::moveBranchUp(BranchObj* bo1) // modify my childlist
 {
 	savePosInAngle();
-    int i=branch.find(bo1);
+    int i=branch.indexOf(bo1);
     if (i>0) 
 	{	// -1 if bo1 not found 
 		branch.at(i)->angle--;
 		branch.at(i-1)->angle++;
-		branch.sort();
-		return branch.at(i-1);
-	} else
+		qSort (branch.begin(),branch.end(), isAbove);
 		return branch.at(i);
+	} else
+		return NULL;
 }
 
 bool BranchObj::canMoveBranchDown() 
 {
-	if (!parObj) return false;
+	if (!parObj|| depth==1) return false;
 	BranchObj* par=(BranchObj*)parObj;
 	if (this==par->getLastBranch())
 		return false;
@@ -1182,28 +1222,28 @@ bool BranchObj::canMoveBranchDown()
 		return true;
 }
 
-BranchObj* BranchObj::moveBranchDown(BranchObj* bo1)
+BranchObj* BranchObj::moveBranchDown(BranchObj* bo1)// modify my childlist
 {
 	savePosInAngle();
-    int i=branch.find(bo1);
+    int i=branch.indexOf(bo1);
 	int j;
-	if (branch.next())
+	if (i <branch.size())
 	{
-		j = branch.at();
+		j = i+1;
 		branch.at(i)->angle++;
 		branch.at(j)->angle--;
-		branch.sort();
-		return branch.at(j);
-	} else
+		qSort (branch.begin(),branch.end(), isAbove);
 		return branch.at(i);
+	} else
+		return NULL;
 }
 
-BranchObj* BranchObj::moveBranchTo (BranchObj* dst, int pos)
+BranchObj* BranchObj::linkTo (BranchObj* dst, int pos)
 {
 	// Find current parent and 
 	// remove pointer to myself there
 	if (!dst) return NULL;
-	BranchObj *par=(BranchObj*)(parObj);
+	BranchObj *par=(BranchObj*)parObj;
 	if (par)
 		par->removeBranchPtr (this);
 	else
@@ -1231,41 +1271,53 @@ BranchObj* BranchObj::moveBranchTo (BranchObj* dst, int pos)
 	}	
 }
 
-void BranchObj::alignRelativeTo (QPoint ref)
+void BranchObj::alignRelativeTo (QPointF ref)
 {
-	int th = bboxTotal.height();	
+	qreal th = bboxTotal.height();	
 // TODO testing
 /*
-	cout << "BO::alignRelTo "<<getHeading()<<endl;
+	cout << "BO::alignRelTo "<<getHeading().ascii()<<endl;
 	cout << "  d="<<depth<<
 		"  ref="<<ref<<
 //		"  bbox.topLeft="<<bboxTotal.topLeft()<<
 		"  absPos="<<absPos<<
+		"  relPos="<<relPos<<
+		"  orient="<<orientation<<
 //		"  pad="<<topPad<<","<<botPad<<","<<leftPad<<","<<rightPad<<
-		"  hidden="<<hidden<<
-		"  th="<<th<<endl;
+//		"  hidden="<<hidden<<
+//		"  th="<<th<<
+		endl;
 */
 
-	// If I am the mapcenter or a mainbranch, reposition heading
+	setOrientation();
+	//updateLink();
+
 	if (depth<2)
-	{	//FIXME ugly! optimize this   move for MCO needed to initially position text in box...
+	{
 		if (depth==1)
+		{
+			// Position relatively, if needed
+			//if (useRelPos) move2RelPos (relPos.x(), relPos.y());
+
 			// Calc angle to mapCenter if I am a mainbranch
 			// needed for reordering the mainbranches clockwise 
 			// around mapcenter 
-			angle=getAngle (QPoint ((int)(x() - parObj->getChildPos().x() ), 
+			angle=getAngle (QPointF ((int)(x() - parObj->getChildPos().x() ), 
 									(int)(y() - parObj->getChildPos().y() ) ) );
+		}							
 	} 
 	else
     {
 		// Align myself depending on orientation and parent, but
-		// only if I am not the mainbranch or mapcenter itself
+		// only if I am not a mainbranch or mapcenter itself
+		LinkableMapObj::Orientation o;
+		o=parObj->getOrientation();
 		switch (orientation) 
 		{
-			case OrientLeftOfCenter:
+			case LinkableMapObj::LeftOfCenter:
 				move (ref.x() - bbox.width(), ref.y() + (th-bbox.height())/2 );
 			break;
-			case OrientRightOfCenter:	
+			case LinkableMapObj::RightOfCenter:	
 				move (ref.x() , ref.y() + (th-bbox.height())/2  );
 			break;
 			default:
@@ -1277,8 +1329,8 @@ void BranchObj::alignRelativeTo (QPoint ref)
 	if (scrolled) return;
 
     // Set reference point for alignment of childs
-    QPoint ref2;
-    if (orientation==OrientLeftOfCenter)
+    QPointF ref2;
+    if (orientation==LinkableMapObj::LeftOfCenter)
 		ref2.setX(bbox.topLeft().x() - linkwidth);
     else	
 		ref2.setX(bbox.topRight().x() + linkwidth);
@@ -1289,13 +1341,12 @@ void BranchObj::alignRelativeTo (QPoint ref)
 		ref2.setY(ref.y() );	
 
     // Align the childs depending on reference point 
-    BranchObj *b;
-    for (b=branch.first(); b; b=branch.next() )
+	for (int i=0; i<branch.size(); ++i)
     {	
-		if (!b->isHidden())
+		if (!branch.at(i)->isHidden())
 		{
-			b->alignRelativeTo (ref2);
-			ref2.setY(ref2.y() + b->getBBoxSizeWithChilds().height() );
+			branch.at(i)->alignRelativeTo (ref2);
+			ref2.setY(ref2.y() + branch.at(i)->getBBoxSizeWithChilds().height() );
 		}
     }
 }
@@ -1305,53 +1356,61 @@ void BranchObj::reposition()
 {	
 /* TODO testing only
 	if (!getHeading().isEmpty())
-		cout << "BO::reposition  "<<getHeading()<<endl;
+		cout << "BO::reposition  "<<getHeading().ascii()<<endl;
 	else	
 		cout << "BO::reposition  ???"<<endl;
+
+	cout << "  orient="<<orientation<<endl;
 */		
+
 	if (depth==0)
 	{
 		// only calculate the sizes once. If the deepest LMO 
 		// changes its height,
 		// all upper LMOs have to change, too.
 		calcBBoxSizeWithChilds();
-		updateLink();	// This update is needed if the canvas is resized 
+		updateLink();	// This update is needed if the scene is resized 
 						// due to excessive moving of a FIO
 
-	    alignRelativeTo ( QPoint (absPos.x(),
+	    alignRelativeTo ( QPointF (absPos.x(),
 			absPos.y()-(bboxTotal.height()-bbox.height())/2) );
-		branch.sort();	
+		qSort (branch.begin(),branch.end(), isAbove);
 		positionBBox();	// Reposition bbox and contents
 	} else
 	{
 		// This is only important for moving branches:
 		// For editing a branch it isn't called...
-	    alignRelativeTo ( QPoint (absPos.x(),
+	    alignRelativeTo ( QPointF (absPos.x(),
 							absPos.y()-(bboxTotal.height()-bbox.height())/2) );
 	}
 }
 
-
-QRect BranchObj::getTotalBBox()
+void BranchObj::unsetAllRepositionRequests()
 {
-	QRect r=bbox;
+	repositionRequest=false;
+	for (int i=0; i<branch.size(); ++i)
+		branch.at(i)->unsetAllRepositionRequests();
+}
+
+
+QRectF BranchObj::getTotalBBox()
+{
+	QRectF r=bbox;
 
 	if (scrolled) return r;
 
-	BranchObj* b;
-	for (b=branch.first();b ;b=branch.next() )
-		if (!b->isHidden())
-			r=addBBox(b->getTotalBBox(),r);
+	for (int i=0; i<branch.size(); ++i)
+		if (!branch.at(i)->isHidden())
+			r=addBBox(branch.at(i)->getTotalBBox(),r);
 
-	FloatImageObj* fio;
-	for (fio=floatimage.first();fio ;fio=floatimage.next() )
-		if (!fio->isHidden())
-			r=addBBox(fio->getTotalBBox(),r);
+	for (int i=0; i<floatimage.size(); ++i)
+		if (!floatimage.at(i)->isHidden())
+			r=addBBox(floatimage.at(i)->getTotalBBox(),r);
 		
 	return r;
 }
 
-QRect BranchObj::getBBoxSizeWithChilds()
+QRectF BranchObj::getBBoxSizeWithChilds()
 {
 	return bboxTotal;
 }
@@ -1392,19 +1451,18 @@ void BranchObj::calcBBoxSizeWithChilds()
 		return;
 	}
 	
-	QRect r(0,0,0,0);
-	QRect br;
+	QRectF r(0,0,0,0);
+	QRectF br;
 	// Now calculate recursivly
 	// sum of heights 
 	// maximum of widths 
 	// minimum of y
-	BranchObj* b;
-	for (b=branch.first();b ;b=branch.next() )
+	for (int i=0; i<branch.size(); ++i)
 	{
-		if (!b->isHidden())
+		if (!branch.at(i)->isHidden())
 		{
-			b->calcBBoxSizeWithChilds();
-			br=b->getBBoxSizeWithChilds();
+			branch.at(i)->calcBBoxSizeWithChilds();
+			br=branch.at(i)->getBBoxSizeWithChilds();
 			r.setWidth( max (br.width(), r.width() ));
 			r.setHeight(br.height() + r.height() );
 			if (br.y()<bboxTotal.y()) bboxTotal.setY(br.y());
@@ -1422,7 +1480,7 @@ void BranchObj::calcBBoxSizeWithChilds()
 
 void BranchObj::select()
 {
-	// set Text in Editor	
+	// update NoteEditor
 	textEditor->setText(note.getNote() );
 	QString fnh=note.getFilenameHint();
 	if (fnh!="")
@@ -1430,8 +1488,11 @@ void BranchObj::select()
 	else	
 		textEditor->setFilenameHint(getHeading() );
 	textEditor->setFontHint (note.getFontHint() );
+	isNoteInEditor=true;
 
+	// set selected and visible
     LinkableMapObj::select();
+
 	// Tell parent that I am selected now:
 	BranchObj* po=(BranchObj*)(parObj);
     if (po)	// TODO	    Try to get rid of this cast...
@@ -1447,9 +1508,9 @@ void BranchObj::select()
 	if (!status.isEmpty()) mainWindow->statusMessage (status);
 
 	// Update Toolbar
-	standardFlags->updateToolbar();
+	updateFlagsToolbar();
 
-	// Update actions in mapeditor
+	// Update actions
 	mapEditor->updateActions();
 }
 
@@ -1459,10 +1520,9 @@ void BranchObj::unselect()
 	// Delete any messages like vymLink in StatusBar
 	mainWindow->statusMessage ("");
 
-	// save note from editor and set flag
-	// text is done by updateNoteFlag(), just save
-	// filename here
-	note.setFilenameHint (textEditor->getFilename());
+	// Save current note
+	if (isNoteInEditor) getNoteFromTextEditor();
+	isNoteInEditor=false;
 
 	// reset temporary unscroll, if we have scrolled parents somewhere
 	if (parObj) ((BranchObj*)(parObj))->resetTmpUnscroll();
@@ -1488,3 +1548,10 @@ QString BranchObj::getSelectString()
 	return s;
 }
 
+
+void BranchObj::animate()
+{
+	//relPos.animate();
+	cout << "BO::animate  x,y="<<relPos.x()<<","<<relPos.y()<<endl;
+}
+
