@@ -1,29 +1,34 @@
 #ifndef EXPORTOOFILEDIALOG
 #define EXPORTOOFILEDIALOG
 
-#include <qfiledialog.h>
-#include <qstringlist.h>
+#include <QFileDialog>
+#include <QStringList>
 
 #include "settings.h"
 
+/*! \brief Dialog to select output file and format for Open Office documents
+
+This is an overloaded QFileDialog, which allows to select templates by setting a type.
+*/
+
 class ExportOOFileDialog:public QFileDialog
 {
 	Q_OBJECT
 public:
 	ExportOOFileDialog();
 
-	ExportOOFileDialog (QWidget * parent = 0, const char * name = 0, bool
-	modal = false);
+	ExportOOFileDialog (QWidget * parent = 0, const  QString &caption=QString());
 	bool foundConfig();
 	QString selectedConfig();
 	QString selectedFile();
-	void addFilter(const QString &);
+	void show();
 	 
 private slots:
 	void  newConfigPath (const QString&f);
 
 private:
 	void init();
+	void addFilter(const QString &);
 	void scanExportConfigs(QDir );
 	QStringList configPaths;
 	QStringList filters;
