@@ -1,18 +1,24 @@
 #ifndef FILE_H
 #define FILE_H
 
-#include <qdir.h>
+#include <QDir>
 
 enum LoadMode {NewMap,ImportAdd,ImportReplace};
 enum SaveMode {PartOfMap,CompleteMap,UndoCommand};
+enum FileType {VymMap, FreemindMap};
 enum ErrorCode {success,aborted,nozip};
 
 
 /////////////////////////////////////////////////////////////////////////////
 QString maskPath (QString );
 QString convertToRel (const QString &,const QString &);
-QString makeUniqueDir (QString);
+
+QString browseDirectory (QWidget *parent=NULL, const QString &caption="");
+bool reallyWriteDirectory(const QString &dir);
+
+QString makeUniqueDir (bool &,QString);
 void removeDir(QDir);
+void copyDir (QDir src,QDir dst);
 void makeSubDirs (const QString &);
 ErrorCode zipDir (const QDir &,const QString&);
 ErrorCode unzipDir (const QDir &,const QString&);
@@ -20,17 +26,33 @@ bool loadStringFromDisk (const QString &, QString &);
 bool saveStringToDisk (const QString &, const QString &s);
 
 /////////////////////////////////////////////////////////////////////////////
-#include <qlabel.h>
-#include <qfiledialog.h>
-#include <qpixmap.h>
+#include <QLabel>
+#include <q3filedialog.h>
+#include <QPixmap>
 
-class ImagePreview : public QLabel, public QFilePreview
+class ImagePreview : public QLabel, public Q3FilePreview
 {
 public:
     ImagePreview( QWidget * );
-    void previewUrl( const QUrl & );
+    void previewUrl( const Q3Url & );
 protected:
-	QFileDialog *fdia;
+	Q3FileDialog *fdia;
+};
+
+
+//////////////////////////////////////////////////////////
+// Helper function to select image format while in SaveDialogs
+
+class ImageIO
+{
+public:
+	ImageIO ();
+	QStringList getFilters();
+	QString getType ( QString );
+
+private:	
+	QStringList imageFilters;
+	QStringList imageTypes;
 };
 
 #endif
