@@ -2,17 +2,23 @@
 #define FLAGOBJ_H
 
 
-#include <qcanvas.h>
-#include <qaction.h>
+#include <QAction>
+#include <QPixmap>
 
 #include "mapobj.h"
 #include "imageobj.h"
 
+/*! \brief One flag which is visible in the map. 
+
+    Flags are aligned in a row. 
+*/
+
+
 /////////////////////////////////////////////////////////////////////////////
 class FlagObj:public MapObj {
 public:
     FlagObj ();
-    FlagObj (QCanvas*);
+    FlagObj (QGraphicsScene*);
     FlagObj (FlagObj*);
     ~FlagObj ();
     virtual void init ();
@@ -26,16 +32,18 @@ public:
 	const QString getName ();
 	void setGroup (const QString&);
 	const QString getGroup();
+	void unsetGroup ();
 	void setToolTip(const QString&);
 	const QString getToolTip();
-	void setButton (QAction*);
-	void updateButton ();
 	QPixmap getPixmap();
+	void setAction(QAction*);
+	void updateAction ();
+	void setAlwaysVisible (bool b);
+	bool isAlwaysVisible ();
 	bool isActive();
 	void toggle();
 	void activate();
 	void deactivate();
-	void setEnabled (bool);
 	void setUsed (bool);
 	bool isUsed();
 	void saveToDir (const QString&, const QString&);
@@ -45,12 +53,13 @@ protected:
 	QString group;
 	QString tooltip;
 	bool state;
+	bool avis;
 	bool used;
     virtual void positionBBox();
     virtual void calcBBoxSize();
 private:
 	ImageObj* icon;
-	QAction* button;
+	QAction* action;
 };
 
 #endif
