@@ -1,15 +1,18 @@
 #ifndef MAPCENTEROBJ_H
 #define MAPCENTEROBJ_H
 
+
+#include <QDate>
+
 #include "branchobj.h"
-#include "xlinkobj.h"
-#include "version.h"
+
+/*! \brief The center of the map is a special branch. */
 
 /////////////////////////////////////////////////////////////////////////////
 class MapCenterObj:public BranchObj {
 public:
     MapCenterObj ();
-    MapCenterObj (QCanvas*);
+    MapCenterObj (QGraphicsScene *);
     ~MapCenterObj ();
     void clear();
     void init();
@@ -18,17 +21,17 @@ public:
     virtual void moveAll   (double,double);
     virtual void moveAllBy (double,double);
     virtual void updateLink();
-    LinkableMapObj* findMapObj(QPoint,LinkableMapObj*);	// find MapObj 
-	virtual QString saveToDir (const QString&,const QString&,int, const QPoint&);// Save data recursivly to tempdir
+    virtual void updateRelPositions();
+    LinkableMapObj* findMapObj(QPointF,LinkableMapObj*);	// find MapObj 
+	virtual QString saveToDir (const QString&,const QString&,int, const QPointF&);// Save data recursivly to tempdir
 	void setVersion(const  QString &);
-	bool checkVersion();				// check if program version is higher than saved version
 	void setAuthor  (const QString &);
 	QString getAuthor ();
 	void setComment (const QString &);
 	QString getComment ();
 	QString getDate();
 private:
-	QString version;					// version string saved in vym file
+	QString version;	//!< version string saved in vym file
 	QString author;
 	QString comment;
 	QDate date;
