@@ -10,11 +10,13 @@ using namespace std;
 
 /////////////////////////////////////////////////////////////////////////////
 QString qpointToString (const QPoint &p);
+QString qpointfToString (const QPointF &p);
 extern ostream &operator<< (ostream &stream, QPoint const &p);
-float getAngle(const QPoint &);
-QPoint normalise (const QPoint &);
+extern ostream &operator<< (ostream &stream, QPointF const &p);
+qreal getAngle(const QPointF &);
+QPointF normalise (const QPointF &);
 QString quotemeta(const QString&);	
-int max (int,int);
+qreal max (qreal,qreal);
 class BranchObj;
 class MapEditor;
 
@@ -23,13 +25,13 @@ class xmlObj
 {
 public:
     xmlObj();
-    QString singleElement(QString,QString);
-    QString beginElement(QString,QString);
-    QString beginElement(QString);
-    QString endElement  (QString);
-    QString attribut    (QString,QString);
-    QString valueElement(QString,QString);
-    QString valueElement(QString,QString,QString);
+    QString singleElement(QString,QString);			// name,attr
+    QString beginElement(QString,QString);			// name,attr
+    QString beginElement(QString);					// name
+    QString endElement  (QString);					// name
+    QString attribut    (QString,QString);			// name, val
+    QString valueElement(QString,QString);			// name, val
+    QString valueElement(QString,QString,QString);	// name, attr, val
     void incIndent();
     void decIndent();
     static int actindent;
