@@ -5,9 +5,9 @@
 /////////////////////////////////////////////////////////////////
 Process::Process()
 {
-	connect( this, SIGNAL(readyReadStderr()),
+	connect( this, SIGNAL(readyReadStandardError()),
 			 this, SLOT(readProcErrout()) );
-	connect( this, SIGNAL(readyReadStdout()),
+	connect( this, SIGNAL(readyReadStandardOutput()),
 			 this, SLOT(readProcStdout()) );
 	clear();		 
 }
@@ -22,23 +22,14 @@ void Process::clear()
 	stdOut="";
 }
 
-void Process::waitFinished()
-{
-	while (isRunning())
-	{
-		// FIXME use some kind of sleep here...
-		system ("sleep 1");
-	}
-}
-
 void Process::readProcErrout()
 {
-	errOut+=readStderr();
+	errOut+=readAllStandardError();
 }
 
 void Process::readProcStdout()
 {
-	stdOut+=readStdout();
+	stdOut+=readAllStandardOutput();
 }
 
 QString Process::getErrout()
