@@ -1,8 +1,8 @@
 #ifndef PROCESS_H
 #define PROCESS_H
 
-#include <qprocess.h>
-#include <qstring.h>
+#include <QProcess>
+#include <QString>
 
 
 using namespace std;
@@ -14,7 +14,6 @@ public:
     Process ();
 	~Process ();
 	void clear();
-	void waitFinished();
 	QString getErrout();
 	QString getStdout();
 	
