@@ -18,7 +18,8 @@ public:
 	void clear();
 	void readSettings(const QString &);
 	void writeSettings(const QString &);
-	QString readEntry (const QString &);
+	QString readEntry (const QString &key, const QString &def=QString());
+	int readNumEntry (const QString &, const int &def=0);
 	void setEntry (const QString &,const QString &);
 private:	
 	QStringList keylist;
@@ -32,6 +33,7 @@ class Settings:public QSettings,public xmlObj
 {
 public:
     Settings ();
+    Settings (const QString & , const QString &);
 	~Settings ();
 	void clear();
 	void clearLocal (const QString &);
