@@ -5,18 +5,20 @@
 
 enum XLinkState {undefinedXLink,initXLink,activeXLink,deleteXLink};
 
+/*! \brief xlinks are used to draw arbitrary connections between branches (BranchObj) in the map. */
+
 /////////////////////////////////////////////////////////////////////////////
 class XLinkObj:public MapObj {
 public:
     XLinkObj ();
-    XLinkObj (QCanvas*);
+    XLinkObj (QGraphicsScene*);
     ~XLinkObj ();
     virtual void init ();
     virtual void copy (XLinkObj*);
 	void setBegin (BranchObj*);
 	BranchObj* getBegin();
 	void setEnd   (BranchObj*);
-	void setEnd   (QPoint);
+	void setEnd   (QPointF);
 	BranchObj* getEnd();
 	void setColor(QColor);
 	QColor getColor();
@@ -35,16 +37,17 @@ public:
 
 private:
 	static int arrowSize;
+	QPen pen;
 	QColor color;
 	int width;
-	QCanvasLine *line;
-	QCanvasPolygon *poly;
+	QGraphicsLineItem *line;
+	QGraphicsPolygonItem *poly;
 	BranchObj *beginBranch;
 	BranchObj *endBranch;
 	BranchObj *visBranch;	// the "visible" part of a partially scrolled link
 	XLinkState xLinkState;	// init during drawing or active
-	QPoint beginPos;
-	QPoint   endPos;
+	QPointF beginPos;
+	QPointF   endPos;
 };
 
 #endif
